#!/usr/bin/python3

# install.py
# ccr . 2021 Mar 03

# ==================================================boilerplate»=====
""" Install the WeeWX Phenology Extension

This script is distributed as part of the Phenology Extension to
WeeWX.  WeeWX is maintained by Tom Keffer and Matthew Wall.  This
script is maintained by Chuck Rhode although it may contain portions
copied from Keffer and Wall or directly inspired by them.

Copyright 2018—2021 by Chuck Rhode.

See LICENSE.txt for your rights.

# =================================================«boilerplate======

Usage:

> wee_extension --install=weewx-phenology-1.1

"""

import sys
import weecfg.extension
try:
    import configobj
    HAS_CONFIGOBJ = True
except ModuleNotFoundError:
    HAS_CONFIGOBJ = False

ZERO = 0
SPACE = ' '
NULL = ''
NUL = '\x00'
NA = -1


def loader():
    return PhenologyInstaller()


class PhenologyInstaller(weecfg.extension.ExtensionInstaller):
    def __init__(self):
        self.audit_python_version()
        self.audit_weewx_version()
        phenology_report_dict = {
            'StdReport': {
                'PhenologyReport': {
                    'skin': 'Phenology',
                    'enable': 'True',
                    'HTML_ROOT': 'phenology'
                    },
                },
            }
        phenology_report_stanza = '''
[StdReport]

    [[PhenologyReport]]
        # This stanza is added by the Phenology Extension.
        skin = Phenology
        enable = True
        HTML_ROOT = phenology
'''
        if HAS_CONFIGOBJ:
            config = configobj.ConfigObj(phenology_report_stanza.splitlines())
        else:
            config = phenology_report_dict
        weecfg.extension.ExtensionInstaller.__init__(
            self,
            version="1.1",
            name='Phenology',
            description='Phenology Extension for WeeWX.',
            author="Chuck Rhode",
            author_email="CRhode@LacusVeris.com",
            config=config,
            files=[
                ("bin/user", [
                    "bin/user/growing_degrees.py",
                    "bin/user/phenology_plotter.py",
                    "bin/user/phenologygenerator.py",
                    "bin/user/phenologyservice.py",
                    ]),
                ("bin/user/docs/Phenology", [
                    "bin/user/docs/Phenology/biblio.shtml",
                    "bin/user/docs/Phenology/chemical_control.shtml",
                    "bin/user/docs/Phenology/context.shtml",
                    "bin/user/docs/Phenology/cydia.shtml",
                    "bin/user/docs/Phenology/digital_computing.shtml",
                    "bin/user/docs/Phenology/gloss.shtml",
                    "bin/user/docs/Phenology/growth_stages.shtml",
                    "bin/user/docs/Phenology/hort_practice.shtml",
                    "bin/user/docs/Phenology/index.shtml",
                    "bin/user/docs/Phenology/installation.shtml",
                    "bin/user/docs/Phenology/models.shtml",
                    "bin/user/docs/Phenology/ndx.shtml",
                    "bin/user/docs/Phenology/phenology_image_generator.shtml",
                    "bin/user/docs/Phenology/research.shtml",
                    "bin/user/docs/Phenology/script.js",
                    "bin/user/docs/Phenology/style.css",
                    "bin/user/docs/Phenology/toc.shtml",
                    "bin/user/docs/Phenology/track_gdd.shtml",
                    "bin/user/docs/Phenology/weewx_extension.shtml",
                    ]),
                ("bin/user/docs/Phenology/imgs", [
                    "bin/user/docs/Phenology/imgs/Backyard 2018 Cumulative GDD F.png",
                    "bin/user/docs/Phenology/imgs/Cutoff Comparison.png",
                    "bin/user/docs/Phenology/imgs/Holbein, Hans the Younger -- Adam and Eve -- 1517 scaled.png",
                    "bin/user/docs/Phenology/imgs/Ideal - Horizontal Cutoff.png",
                    "bin/user/docs/Phenology/imgs/Ideal - Intermediate Cutoff.png",
                    "bin/user/docs/Phenology/imgs/Ideal - No Cutoff - Avg.gt.Threshold.png",
                    "bin/user/docs/Phenology/imgs/Ideal - No Cutoff - Avg.lt.Threshold.png",
                    "bin/user/docs/Phenology/imgs/Ideal - No Cutoff - Max.lt.Threshold.png",
                    "bin/user/docs/Phenology/imgs/Ideal - No Cutoff - Min.gt.Threshold.png",
                    "bin/user/docs/Phenology/imgs/Ideal - No Cutoff.png",
                    "bin/user/docs/Phenology/imgs/Ideal - Vertical Cutoff.png",
                    "bin/user/docs/Phenology/imgs/KSBM 1997-2018 Cumulative GDD F.png",
                    "bin/user/docs/Phenology/imgs/KSBM 1997-2018 Temp F.png",
                    "bin/user/docs/Phenology/imgs/KSBM Jul-Aug Avg Temp F.png",
                    "bin/user/docs/Phenology/imgs/KSBM Jul-Aug Sin Temp F.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Blackboard.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Cumulative GDD Report.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Filled Solid.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Filled Transparent.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Flexowriter.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Greenboard.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Navigator.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Seasons.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Sperry 1100.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Spring.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Woods.png",
                    "bin/user/docs/Phenology/imgs/Screenshot -- Yellowboard.png",
                    "bin/user/docs/Phenology/imgs/adult.jpg",
                    "bin/user/docs/Phenology/imgs/cocoon.jpg",
                    "bin/user/docs/Phenology/imgs/eggs.jpg",
                    "bin/user/docs/Phenology/imgs/frass.jpg",
                    "bin/user/docs/Phenology/imgs/larva.jpg",
                    "bin/user/docs/Phenology/imgs/left_gutter.png",
                    "bin/user/docs/Phenology/imgs/multi-season_plastic_delta_trap_2.jpg",
                    "bin/user/docs/Phenology/imgs/pupa.jpg",
                    "bin/user/docs/Phenology/imgs/van Gogh -- Flowering Almond Tree Branch in a Glass -- 1888 scaled.png",
                    "bin/user/docs/Phenology/imgs/van Gogh -- Le Moulin de la Galette -- 1887 scaled.png",
                    "bin/user/docs/Phenology/imgs/van Gogh -- Orchard with Flowering Apricot-Trees -- 1888 scaled.png",
                    "bin/user/docs/Phenology/imgs/van Gogh -- Plain at Auvers with Rain Clouds -- 1890 scaled.png",
                    ]),
                ("skins/Phenology", [
                    "skins/Phenology/Gutter Shading.png",
                    "skins/Phenology/about.inc",
                    "skins/Phenology/analytics.inc",
                    "skins/Phenology/celestial.html.tmpl",
                    "skins/Phenology/celestial.inc",
                    "skins/Phenology/cumulative_growing_degree_days.html.tmpl",
                    "skins/Phenology/current.inc",
                    "skins/Phenology/favicon.ico",
                    "skins/Phenology/hilo.inc",
                    "skins/Phenology/identifier.inc",
                    "skins/Phenology/index.html.tmpl",
                    "skins/Phenology/map.inc",
                    "skins/Phenology/phenology.conf",
                    "skins/Phenology/phenology.css",
                    "skins/Phenology/radar.inc",
                    "skins/Phenology/rss.xml.tmpl",
                    "skins/Phenology/satellite.inc",
                    "skins/Phenology/seasons.css",
                    "skins/Phenology/seasons.js",
                    "skins/Phenology/sensors.inc",
                    "skins/Phenology/skin.conf",
                    "skins/Phenology/statistics.html.tmpl",
                    "skins/Phenology/statistics.inc",
                    "skins/Phenology/sunmoon.inc",
                    "skins/Phenology/tabular.html.tmpl",
                    "skins/Phenology/telemetry.html.tmpl",
                    "skins/Phenology/titlebar.inc",
                    ]),
                ("skins/Phenology/font", [
                    "skins/Phenology/font/OpenSans-Bold.ttf",
                    "skins/Phenology/font/OpenSans-Regular.ttf",
                    "skins/Phenology/font/OpenSans.woff",
                    "skins/Phenology/font/OpenSans.woff2",
                    "skins/Phenology/font/license.txt",
                    ]),
                ("skins/Phenology/icons", [
                    "skins/Phenology/icons/Clouds 50%.png",
                    "skins/Phenology/icons/Corn 50%.png",
                    "skins/Phenology/icons/Corn.jpg",
                    "skins/Phenology/icons/GRTE 2018 Jun 2 12.30.jpg",
                    "skins/Phenology/icons/GRTE 2018 Jun 2 6.00.jpg",
                    "skins/Phenology/icons/GRTE 2018 Sep 17 12.00.jpg",
                    "skins/Phenology/icons/GRTE 2018 Sep 17 17.15.jpg",
                    "skins/Phenology/icons/GRTE 2019 Aug 22 10.45.jpg",
                    "skins/Phenology/icons/GRTE 2019 Aug 23 6.30.jpg",
                    "skins/Phenology/icons/GRTE 2021 Jan 19 12.00.jpg",
                    "skins/Phenology/icons/GRTE 2021 Jan 19 17.45.jpg",
                    "skins/Phenology/icons/GRTE.Fall.Dusk 50%.png",
                    "skins/Phenology/icons/GRTE.Fall.Noon 50%.png",
                    "skins/Phenology/icons/GRTE.Fall.Noon 70%.png",
                    "skins/Phenology/icons/GRTE.Spring.Dawn 50%.png",
                    "skins/Phenology/icons/GRTE.Spring.Noon 50%.png",
                    "skins/Phenology/icons/GRTE.Summer.Dawn 50%.png",
                    "skins/Phenology/icons/GRTE.Summer.Dawn 70%.png",
                    "skins/Phenology/icons/GRTE.Summer.Midmorning 50%.png",
                    "skins/Phenology/icons/GRTE.Summer.Midmorning 70%.png",
                    "skins/Phenology/icons/GRTE.Winter.Dusk 50%.png",
                    "skins/Phenology/icons/GRTE.Winter.Noon 50%.png",
                    "skins/Phenology/icons/Mexican_poppies_and_mountains.jpg",
                    "skins/Phenology/icons/North_Pointer.png",
                    "skins/Phenology/icons/North_Pointer.svg",
                    "skins/Phenology/icons/Photo_Wheat.jpg",
                    "skins/Phenology/icons/Poppies 50%.png",
                    "skins/Phenology/icons/README.html",
                    "skins/Phenology/icons/Wheat 50%.png",
                    "skins/Phenology/icons/Winter Trees 30%.png",
                    "skins/Phenology/icons/Winter Trees 50%.png",
                    "skins/Phenology/icons/cirrus.jpg",
                    "skins/Phenology/icons/hinter-winter-land.jpg",
                    ]),
                ],
            xtype_services=[
                'user.phenologyservice.PhenologyService',
                ],
            )
        return

    def audit_python_version(self):
        version = sys.version_info
        if list(version) > [3]:
            pass
        else:
            print('Error:  The Phenology Extension requires WeeWX to run on Python 3.')
            sys.exit(0x10)
        return self

    def audit_weewx_version(self):
        return self


def main_line():
    return


if __name__ == "__main__":
    main_line()


# Fin
